########################################################################################################################################################
# Written by  : Catherine J Pink
# Created on  : 29/04/2009
# Modified on : 
# Input files : 
#
#
# Script to combine replication domain data tables
# This can't be done just be extracting columns as it is necessary to ensure each value relates to the same location
# This can be done using arrays
#
#
#
#
#
########################################################################################################################################################


package provide 21_combine_replication_tables 1.0

proc 21_combine_replication_tables {} {

	puts "-----------------------------------------------------------"
	puts "21              COMBINE REPLICATION TABLES                \n"
	
	# Make variables global
	global contents
	
	
	# Find files containing replication timing data
	cd Input_Files
	set filelist [lsort [glob *081128.txt]]
	
	set LIST_GeneID {}
	
	# Extract information about chromosome, position and data value for each gene in each dataset and store in arrays	

	foreach datafile $filelist {
	
		regexp {RD_(.+)_Sm300_081128\.txt} $datafile all DataSet
		lappend LIST_DataSet $DataSet
		puts "Filename $datafile \tname $DataSet"
		
		openfile $datafile
		set contents [split $contents \n]
		set contents [lrange $contents 1 end-1]
		
		foreach dataline $contents {
			set GeneID [lindex $dataline 0]
			set Chromosome [lindex $dataline 2]
			set StartPosition [lindex $dataline 3]
			set EndPosition [lindex $dataline 4]
			set DataValue [lindex $dataline 5]
			
			lappend GeneList $GeneID
			lappend LIST_GeneID $GeneID
			set ARRAY_INFO($DataSet,$GeneID) "$Chromosome $StartPosition $EndPosition $DataValue "
			
			unset GeneID Chromosome StartPosition EndPosition DataValue
		}
		
		if {[llength $GeneList] != [llength [lsort -unique $GeneList]]} {puts "Duplicate gene ID in $DataSet"}
		
		unset dataline contents
		unset all DataSet
		unset GeneList
	}
	unset datafile filelist
	
	cd ..
	
	# Create output file
	foreach c {1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 X Y ALL} {
		set outTXT($c) [open CombinedReplicationTables-$c.txt w]
		puts $outTXT($c) "GeneID\tChromosome\tStartPosition\tEndPosition\tValue_[lindex $LIST_DataSet 0]\tValue_[lindex $LIST_DataSet 1]\tValue_[lindex $LIST_DataSet 2]\tValue_[lindex $LIST_DataSet 3]"
	}
	unset c

	# For each gene, extract the chromosome, positions and data value from each of the 4 datasets
	set LIST_GeneID [lsort -unique $LIST_GeneID]
	foreach gene $LIST_GeneID {
		
		# Obtain information for this gene from each cell line dataset
		set ds1 [lindex $LIST_DataSet 0]
		set ds2 [lindex $LIST_DataSet 1]
		set ds3 [lindex $LIST_DataSet 2]
		set ds4 [lindex $LIST_DataSet 3]
		
		set chr1 [lindex $ARRAY_INFO($ds1,$gene) 0]
		set chr2 [lindex $ARRAY_INFO($ds2,$gene) 0]
		set chr3 [lindex $ARRAY_INFO($ds3,$gene) 0]
		set chr4 [lindex $ARRAY_INFO($ds4,$gene) 0]
		
		set start1 [lindex $ARRAY_INFO($ds1,$gene) 1]
		set start2 [lindex $ARRAY_INFO($ds2,$gene) 1]
		set start3 [lindex $ARRAY_INFO($ds3,$gene) 1]
		set start4 [lindex $ARRAY_INFO($ds4,$gene) 1]
		
		set end1 [lindex $ARRAY_INFO($ds1,$gene) 2]
		set end2 [lindex $ARRAY_INFO($ds2,$gene) 2]
		set end3 [lindex $ARRAY_INFO($ds3,$gene) 2]
		set end4 [lindex $ARRAY_INFO($ds4,$gene) 2]
		
		set value1 [lindex $ARRAY_INFO($ds1,$gene) 3]
		set value2 [lindex $ARRAY_INFO($ds2,$gene) 3]
		set value3 [lindex $ARRAY_INFO($ds3,$gene) 3]
		set value4 [lindex $ARRAY_INFO($ds4,$gene) 3]
			
		set error 0
		# Check details for this gene are the same in all cell line datasets
		if {$chr1 == $chr2 && $chr1 == $chr3 && $chr1 == $chr4} {set outchr $chr1} else {incr error}
		if {$start1 == $start2 && $start1 == $start3 && $start1 == $start4} {set outstart $start1} else {incr error}
		if {$end1 == $end2 && $end1 == $end3 && $end1 == $end4} {set outend $end1} else {incr error}
		
		# If details are the same in all cell lines datasets, send combined replication values to new output files
		if {$error == 0} {
			regexp {chr(.+)} $outchr all chromosome
			puts $outTXT($chromosome) "$gene\t$chromosome\t$outstart\t$outend\t$value1\t$value2\t$value3\t$value4"
			puts $outTXT(ALL) "$gene\t$chromosome\t$outstart\t$outend\t$value1\t$value2\t$value3\t$value4"
			unset outchr outstart outend all chromosome
		}
		unset error
	
		# Unset array elements to save time
		unset ARRAY_INFO($ds1,$gene)
		unset ARRAY_INFO($ds2,$gene)
		unset ARRAY_INFO($ds3,$gene)
		unset ARRAY_INFO($ds4,$gene)
	
		unset ds1 ds2 ds3 ds4 
		unset chr1 chr2 chr3 chr4 		
		unset start1 start2 start3 start4 
		unset end1 end2 end3 end4 
		unset value1 value2 value3 value4 
		
	}
	unset gene

	# Close output files and send to Output_Files directory
	foreach c {1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 X Y ALL} {
		close $outTXT($c)
		unset outTXT($c)	
		exec mv CombinedReplicationTables-$c.txt Output_Files/CombinedReplicationTables-$c.txt
	}
	unset c
	
	# Unset variables	
	unset LIST_DataSet LIST_GeneID ARRAY_INFO
	unset outTXT
	
	puts "\nVariables open in combine_replication_tables : [info local]"

return
}






