########################################################################################################################################################
# Written by  	: Catherine J Pink
#
# Created on  	: 29/07/2009
# Modified on 	: 30/07/2009 (check correct amount of bases counted by comparison to intron lengths)
# 				  30/07/2009 (Addition of GT skew to output file)
# 				  31/07/2009 (Output of three column file for LDH partial correlation script)
#
# Input files 	: K_gene_RepTime_genic.txt
#				  (Output by tcl script allocate_RepTime_Kgenes_genic.tcl and stored in Output_Files directory)
#				  		  
# Output files  : 
#				  				 
#
# Replication time is also known to correlate with expression with highly expressed genes replicationg early and 
# lowly expressed genes replicating late. Therefore, it is possible that the relationship between substitution rates and 
# replication time is the result, not of late replicating DNA having a higher substitution rate, but of highly expressed
# (and therefore early replicating DNA) having a lower substitution rate.
# I therefore need to be able to control for expression level and see if the relactionship between substitution rate and
# replication time still holds.
# 
# subsitution rate effect is not a result 
# late replicating sequence but that 
# Need to go back into the original sequence files and calculate percentage ACTG for each intron.
#
#
#
#
#
########################################################################################################################################################

package provide 25_GT_skew.tcl

proc 25_GT_skew {} {

	puts "-----------------------------------------------------------"
	puts "25                 CALCULATING GT SKEW                     \n"
	
	# Make variables global
	global contents
	
	# 1. Get list of all genes for which I want data on GT skew
	set RefSeqs_Mouse {}
	set RefSeqs_Rat {}

	# Create new file for results
	set outTXT [open K_gene_RepTime_genic_GT.txt w]
	set outXLS [open K_gene_RepTime_genic_GT.xls w]
	
	puts $outTXT "Ortholog\tMouse_Chromosome\tRat_Chromosome\tMouse_Refseq\tRat_Refseq\tIntrons_Concatenated\tMouse_Start_mm9\tMouse_End_mm9\tMouse_Start_mm8\tMouse_End_mm8\tRat_Start\tRat_End\tAlignment_Length\tN\tK_JC\tK_Kimura\tK_TN\tK_TK\traw_subst\traw_subst_per_site\tGC\tClass\tNumber_Replication_Regions\tMean_RT\tMedian_RT\tMean_RT_start\tMean_RT_end\tMean_RT_difference\tMedian_RT_start\tMedian_RT_end\tMedian_RT_difference\tA\tT\tG\tC\tN\tGT_SKEW"
	puts $outXLS "Ortholog\tMouse_Chromosome\tRat_Chromosome\tMouse_Refseq\tRat_Refseq\tIntrons_Concatenated\tMouse_Start_mm9\tMouse_End_mm9\tMouse_Start_mm8\tMouse_End_mm8\tRat_Start\tRat_End\tAlignment_Length\tN\tK_JC\tK_Kimura\tK_TN\tK_TK\traw_subst\traw_subst_per_site\tGC\tClass\tNumber_Replication_Regions\tMean_RT\tMedian_RT\tMean_RT_start\tMean_RT_end\tMean_RT_difference\tMedian_RT_start\tMedian_RT_end\tMedian_RT_difference\tA\tT\tG\tC\tN\tGT_SKEW"

	set out3col [open partialcorinput.txt w]
	puts $out3col "RT\tKTK\tGTskew"



	cd Output_Files
	openfile K_gene_RepTime_genic.txt
	cd ..
	set contents1 [split $contents \n]
	set contents1 [lrange $contents1 1 end-1]
	unset contents
	set count 0
	foreach datarow $contents1 {
		
		if {[lindex $datarow 21] != "Y" & [lindex $datarow 21] != "X"} {
		incr count
		puts "$count of [llength $contents1]"
#		puts $datarow
		
		set refseqmouse [lindex $datarow 3]
	
set seqlength 0
set basecount 0		
		
		# Initiate base counts for this gene
		foreach base {a t c g n} {set $base 0}; unset base
		
		# Find mouse file
		cd Intron_Data/INTRONS_Mouse
		openfile IN_$refseqmouse.txt
		cd ../..
		
		
		# Seperate out mouse intronic sequences
		set contents [split $contents >]
		set contents [lrange $contents 1 end]
		foreach intron $contents {
	
			# Extract the sequence & count the bases
			set sequence [split $intron \n]
			set sequence [lindex $sequence 1]
			
			set seqlength [expr {$seqlength + [string length $sequence]}]
		
			for {set position 0} {$position < [string length $sequence]} {incr position} {
				set base [string index $sequence $position]
				if {[regexp {[agct]} $base]} {incr $base} else {incr n}
				unset base
			}; unset position sequence
				
		
		}; unset intron contents
	
	
		set basecount [expr {$a + $t + $c +$g +$n}]

		set GTskew [expr {[expr {[expr {[format %f $g] + $t}] - [expr {$a + $c}]}] / [expr {$a + $t + $g + $c}]}]

		puts $outTXT "$datarow\t$a\t$t\t$g\t$c\t$n\t$GTskew"
		puts $outXLS "$datarow\t$a\t$t\t$g\t$c\t$n\t$GTskew"
		
		puts $out3col "[lindex $datarow 23]\t[lindex $datarow 17]\t$GTskew"
	
		unset refseqmouse
		unset a t c g n
		unset GTskew
		
		if {$seqlength != $basecount} {puts "ERROR...Mistake in base counting as not equal to sequence length"; exit}

	}
	}; unset datarow contents1
	
	# Close output file
	close $outTXT
	close $outXLS
	
	close $out3col
	
	exec mv  K_gene_RepTime_genic_GT.txt Output_Files/K_gene_RepTime_genic_GT.txt
	exec mv  K_gene_RepTime_genic_GT.xls Output_Files/K_gene_RepTime_genic_GT.xls
	
	exec mv partialcorinput.txt Output_Files/partialcorinput.txt
	
	puts "\nVariables open in GT_skew : [info local]"
	
return
}
