########################################################################################################################################################
# Written by  	: Catherine J Pink
#
# Created on  	: 12/05/2009
# Modified on 	: 13/05/2009 (Completion of script)
#
# Input files 	: Procedure receives 2 alignments when the procedure is called.				  
#				  
# Output files  : Procedure hands back an answer to the test.
#				  This is stored in the variable 'parameter1' and is either 'passed' or 'failed'
#				  
# The sequences are extracted from the two alignments and the length of the longest sequence determined.
# The alignments are checked to ensure that they are the same length and the alignment length determined.
# The ratio of the alignment length to the longest sequence length is determined.
# This ratio is compared to the critical value of 1.16 (Chamary et al 2004).
# Ratios exceeding 1.16 are deemed to have failed the alignment parameter.
# A variable 'parameter1' is handed back to the previous environment as either 'passed' or 'failed'
#
########################################################################################################################################################

package provide INTRONS10_parameter1 1.0

proc INTRONS10_parameter1 {alignment1 alignment2} {
	
	# Make output variable global
	global parameter1
	global ratio1
	
	# Extract sequences from alignment
	regsub -all {\-} $alignment1 "" sequence1
	regsub -all {\-} $alignment2 "" sequence2
	
	# Determine longest sequence length (and format as floating point integer for ratio calculation)
	if {[string length $sequence1] > [string length $sequence2]} {
		set longestsequencelength [format %f [string length $sequence1]]
	} else {
		set longestsequencelength [format %f [string length $sequence2]]
	}
	
	# Determine alignment length (and format as floating point integer for ratio calculation)
	if {[string length $alignment1] != [string length $alignment2]} {
		puts "ERROR...$alignmentfile alignments not the same length"
		exit
	} else {
		set alignmentlength [format %f [string length $alignment1]]
	}
	
	# Determine ratio of alignment length to longest sequence length
	set ratio1 [expr {$alignmentlength / $longestsequencelength}]
	
	# Compare ratio to critial parameter value
	if {$ratio1 > 1.16} {
		set parameter1 failed
	} else {
		set parameter1 passed
	}
	
return
}