########################################################################################################################################################
# Written by  	: Catherine J Pink
#
# Created on  	: 28/01/2008 (As part of MMBIntrons work)
# Modified on 	: 13/05/2009 (Completion of script)
#
# Input files 	: Procedure receives 2 alignments containing indels when the procedure is called.
#				  
# Output files  : Procedure hands back aligned nucleotides only.
#				  These indel free alignments are stored in the variables 'alignmentNOINDELSmouse' and 'alignmentNOINDELSrat'
#				  
# This script removes all positions that are an indel in either alignment from both alignments.
# It works through each position of the input alignments.
# If this position contains aligned nucleotides (not an indel '-') then it appends each aligned base to a string.
# It then hands back two sequence alignments having had all indels removed.
#
########################################################################################################################################################

package provide INTRONS12_removeindels 1.0

proc INTRONS12_removeindels {alignment1 alignment2} {
	
	# Make variables global
	global alignmentNOINDELSmouse
	global alignmentNOINDELSrat

	# Initiate variables to store aligned bases
	set alignmentNOINDELSmouse {}
	set alignmentNOINDELSrat {}
		
	# Work through each position of each alignment string
	for {set position 0} {$position < [string length $alignment1]} {incr position} {

		# Identify the character in each alignment
		set mousebase [string index $alignment1 $position]
		set ratbase [string index $alignment2 $position]

		# If neither character is an indel (it is a pair of aligned bases) append each character to new string
		if {$mousebase != "-" && $ratbase != "-"} {
			append alignmentNOINDELSmouse $mousebase
			append alignmentNOINDELSrat $ratbase
		} 
		unset mousebase ratbase
	}
	unset position
		
	# Ensure each new sequence of aligned bases is the same length
	if {[string length $alignmentNOINDELSmouse] != [string length $alignmentNOINDELSrat]} {
		puts "Error...Aligned sequences after indel remove not the same length [string length $alignmentNOINDELSmouse] and [string length $alignmentNOINDELSrat]"
		exit
	}
	
return	
}